Usage — django-ordinary-news v0.0.1 documentation

### Navigation

- index
- previous |
- django-ordinary-news v0.0.1 documentation »

# Usage

Usage is simple, just follow the install and you got an working application.

You can also redefine news templates.

## Templates

Ordinary news uses following templates:

> - news/newsitem.html

>   > common template, wich included in news lists

> - news/newsitem_archive.html

>   > template for django.views.generic.date_based.archive_index view

> - news/newsitem_archive_year.html

>   > template for django.views.generic.date_based.archive_year view

> - news/newsitem_archive_month.html

>   > template for django.views.generic.date_based.archive_month view

> - news/newsitem_archive_day.html

>   > template for django.views.generic.date_based.archive_day view

> - news/newsitem_detail.html

>   > template for django.views.generic.list_detail.object_detail view

As you can see, application uses django generic views for context lookup take a look into django documentation

### Navigation

- index
- previous |
- django-ordinary-news v0.0.1 documentation »